pub enum Event {
Request(Request),
NormalResponse(Response),
InformationalResponse(Response),
Data(Data),
EndOfMessage(EndOfMessage),
ConnectionClosed(ConnectionClosed),
NeedData(),
Paused(),
}Expand description
Protocol events emitted and accepted by crate::Connection.
Variants
Request(Request)
Request head event.
NormalResponse(Response)
Final response head event with status code >= 200.
InformationalResponse(Response)
Informational response head event with status code in 100..=199.
Data(Data)
Message body data.
EndOfMessage(EndOfMessage)
End of a request or response message.
ConnectionClosed(ConnectionClosed)
Connection close notification.
NeedData()
More bytes are needed before another inbound event can be produced.
Paused()
Inbound data is paused until the current cycle is completed.
Implementations
Sourceimpl Event
impl Event
Sourcepub fn informational_response(response: Response) -> Result<Self, ProtocolError>
pub fn informational_response(response: Response) -> Result<Self, ProtocolError>
Converts a validated response into an informational response event.
Sourcepub fn normal_response(response: Response) -> Result<Self, ProtocolError>
pub fn normal_response(response: Response) -> Result<Self, ProtocolError>
Converts a validated response into a final response event.